@@ -22,18 +22,15 @@ from stat import (
     S_ISDIR,
 )
 from typing import (
-    Optional,
-    Union,
     Any,
-    Tuple,
     cast,
     AnyStr,
     TYPE_CHECKING,
-    Callable,
     IO,
-    List,
 )
 
+from collections.abc import Callable
+
 from pyfakefs import helpers
 from pyfakefs.fake_file import (
     FakePipeWrapper,
@@ -73,20 +70,23 @@ _OPEN_MODE_MAP = {
 
 def fake_open(
     filesystem: "FakeFilesystem",
-    skip_names: List[str],
-    file: Union[AnyStr, int],
+    skip_names: list[str],
+    file: AnyStr | int,
     mode: str = "r",
     buffering: int = -1,
-    encoding: Optional[str] = None,
-    errors: Optional[str] = None,
-    newline: Optional[str] = None,
+    encoding: str | None = None,
+    errors: str | None = None,
+    newline: str | None = None,
     closefd: bool = True,
-    opener: Optional[Callable] = None,
-) -> Union[AnyFileWrapper, IO[Any]]:
+    opener: Callable | None = None,
+    is_fake_open_code: bool = False,
+) -> AnyFileWrapper | IO[Any]:
     """Redirect the call to FakeFileOpen.
     See FakeFileOpen.call() for description.
     """
-    if is_called_from_skipped_module(
+    # We don't need to check this if we are in an `open_code` call
+    # from a faked file (and this might cause recursions in `linecache`)
+    if not is_fake_open_code and is_called_from_skipped_module(
         skip_names=skip_names,
         case_sensitive=filesystem.is_case_sensitive,
         check_open_code=sys.version_info >= (3, 12),
@@ -110,8 +110,8 @@ def fake_open(
 class FakeFileOpen:
     """Faked `file()` and `open()` function replacements.
 
-    Returns FakeFile objects in a FakeFilesystem in place of the `file()`
-    or `open()` function.
+    Returns :py:class:`FakeDirectory<pyfakefs.fake_file.FakeFile>` objects in a
+        fake filesystem; replaces the `open()` function.
     """
 
     __name__ = "FakeFileOpen"
@@ -137,15 +137,15 @@ class FakeFileOpen:
 
     def call(
         self,
-        file_: Union[AnyStr, int],
+        file_: AnyStr | int,
         mode: str = "r",
         buffering: int = -1,
-        encoding: Optional[str] = None,
-        errors: Optional[str] = None,
-        newline: Optional[str] = None,
+        encoding: str | None = None,
+        errors: str | None = None,
+        newline: str | None = None,
         closefd: bool = True,
         opener: Any = None,
-        open_modes: Optional[_OpenModes] = None,
+        open_modes: _OpenModes | None = None,
     ) -> AnyFileWrapper:
         """Return a file-like object with the contents of the target
         file object.
@@ -157,7 +157,7 @@ class FakeFileOpen:
                 flushed if buffer size is exceeded. The default (-1) uses a
                 system specific default buffer size. Text line mode (e.g.
                 buffering=1 in text mode) is not supported.
-            encoding: The encoding used to encode unicode strings / decode
+            encoding: The encoding used to encode Unicode strings / decode
                 bytes.
             errors: (str) Defines how encoding errors are handled.
             newline: Controls universal newlines, passed to stream object.
@@ -267,9 +267,8 @@ class FakeFileOpen:
         fakefile = FakeFileWrapper(
             file_object,
             file_path,
-            update=open_modes.can_write and can_write,
-            read=open_modes.can_read,
-            append=open_modes.append,
+            open_modes=open_modes,
+            allow_update=open_modes.can_write and can_write,
             delete_on_close=self._delete_on_close,
             filesystem=self.filesystem,
             newline=newline,
@@ -313,7 +312,7 @@ class FakeFileOpen:
 
     def _init_file_object(
         self,
-        file_object: Optional[FakeFile],
+        file_object: FakeFile | None,
         file_path: AnyStr,
         open_modes: _OpenModes,
         real_path: AnyString,
@@ -361,10 +360,8 @@ class FakeFileOpen:
         return file_object
 
     def _handle_file_arg(
-        self, file_: Union[AnyStr, int]
-    ) -> Tuple[
-        Optional[FakeFile], Optional[AnyStr], Optional[int], Optional[AnyStr], bool
-    ]:
+        self, file_: AnyStr | int
+    ) -> tuple[FakeFile | None, AnyStr | None, int | None, AnyStr | None, bool]:
         file_object = None
         if isinstance(file_, int):
             # opening a file descriptor
@@ -406,9 +403,9 @@ class FakeFileOpen:
     def _handle_file_mode(
         self,
         mode: str,
-        newline: Optional[str],
-        open_modes: Optional[_OpenModes],
-    ) -> Tuple[Optional[str], _OpenModes]:
+        newline: str | None,
+        open_modes: _OpenModes | None,
+    ) -> tuple[str | None, _OpenModes]:
         orig_modes = mode  # Save original modes for error messages.
         # Normalize modes. Handle 't' and 'U'.
         if ("b" in mode and "t" in mode) or (
