@@ -25,19 +25,15 @@ from stat import (
 )
 from types import ModuleType
 from typing import (
-    Callable,
-    List,
-    Optional,
-    Union,
     Any,
-    Dict,
-    Tuple,
     AnyStr,
     overload,
     ClassVar,
     TYPE_CHECKING,
 )
 
+from collections.abc import Callable
+
 from pyfakefs.helpers import (
     is_called_from_skipped_module,
     make_string_path,
@@ -63,20 +59,20 @@ def _copy_module(old: ModuleType) -> ModuleType:
 class FakePathModule:
     """Faked os.path module replacement.
 
-    FakePathModule should *only* be instantiated by FakeOsModule.  See the
-    FakeOsModule docstring for details.
+    `FakePathModule` should *only* be instantiated by `FakeOsModule`.  See the
+    :py:class:`FakeDirectory<pyfakefs.fake_os.FakeOsModule>` docstring for details.
     """
 
     _OS_PATH_COPY: Any = _copy_module(os.path)
 
     devnull: ClassVar[str] = ""
     sep: ClassVar[str] = ""
-    altsep: ClassVar[Optional[str]] = None
+    altsep: ClassVar[str | None] = None
     linesep: ClassVar[str] = ""
     pathsep: ClassVar[str] = ""
 
     @staticmethod
-    def dir() -> List[str]:
+    def dir() -> list[str]:
         """Return the list of patched function names. Used for patching
         functions imported from the module.
         """
@@ -139,7 +135,7 @@ class FakePathModule:
         return self.filesystem.exists(path)
 
     def lexists(self, path: AnyStr) -> bool:
-        """Test whether a path exists.  Returns True for broken symbolic links.
+        """Test whether a path exists.  Returns `True` for broken symbolic links.
 
         Args:
           path:  path to the symlink object.
@@ -163,12 +159,11 @@ class FakePathModule:
             self.filesystem.ends_with_path_separator(path)
             and S_IFMT(file_obj.st_mode) != S_IFDIR
         ):
-            error_nr = errno.EINVAL if self.filesystem.is_windows_fs else errno.ENOTDIR
-            self.filesystem.raise_os_error(error_nr, path)
+            self.filesystem.raise_os_error(errno.ENOTDIR, path)
         return file_obj.st_size
 
     def isabs(self, path: AnyStr) -> bool:
-        """Return True if path is an absolute pathname."""
+        """Return `True` if path is an absolute pathname."""
         empty = matching_string(path, "")
         if self.filesystem.is_windows_fs:
             drive, path = self.splitdrive(path)
@@ -201,14 +196,14 @@ class FakePathModule:
             `True` if path points to a symbolic link.
 
         Raises:
-            TypeError: if path is None.
+            TypeError: if path is `None`.
         """
         return self.filesystem.islink(path)
 
     if sys.version_info >= (3, 12):
 
         def isjunction(self, path: AnyStr) -> bool:
-            """Returns False. Junctions are never faked."""
+            """Returns `False`. Junctions are never faked."""
             return self.filesystem.isjunction(path)
 
         def splitroot(self, path: AnyStr):
@@ -311,11 +306,11 @@ class FakePathModule:
         """Return the completed path with a separator of the parts."""
         return self.filesystem.joinpaths(*p)
 
-    def split(self, path: AnyStr) -> Tuple[AnyStr, AnyStr]:
+    def split(self, path: AnyStr) -> tuple[AnyStr, AnyStr]:
         """Split the path into the directory and the filename of the path."""
         return self.filesystem.splitpath(path)
 
-    def splitdrive(self, path: AnyStr) -> Tuple[AnyStr, AnyStr]:
+    def splitdrive(self, path: AnyStr) -> tuple[AnyStr, AnyStr]:
         """Split the path into the drive part and the rest of the path, if
         supported."""
         return self.filesystem.splitdrive(path)
@@ -332,7 +327,7 @@ class FakePathModule:
             path = path.lower()
         return path
 
-    def relpath(self, path: AnyStr, start: Optional[AnyStr] = None) -> AnyStr:
+    def relpath(self, path: AnyStr, start: AnyStr | None = None) -> AnyStr:
         """We mostly rely on the native implementation and adapt the
         path separator."""
         if not path:
@@ -355,15 +350,25 @@ class FakePathModule:
         path = self._os_path.relpath(path, start)
         return path.replace(system_sep, sep)
 
-    def realpath(self, filename: AnyStr, strict: Optional[bool] = None) -> AnyStr:
+    def realpath(self, filename: AnyStr, strict: bool | None = None) -> AnyStr:
         """Return the canonical path of the specified filename, eliminating any
         symbolic links encountered in the path.
         """
-        if strict is not None and sys.version_info < (3, 10):
-            raise TypeError("realpath() got an unexpected keyword argument 'strict'")
-        if strict:
-            # raises in strict mode if the file does not exist
+        has_allow_missing = hasattr(os.path, "ALLOW_MISSING")
+        if has_allow_missing and strict == os.path.ALLOW_MISSING:  # type: ignore[attr-defined]
+            # ignores non-existing file, but not other errors
+            ignored_error: Any = FileNotFoundError
+        elif strict:
+            # raises on any errors
+            ignored_error = ()
+        else:
+            # ignores any OSError while resolving the filename
+            ignored_error = OSError
+        try:
             self.filesystem.resolve(filename)
+        except ignored_error:
+            pass
+
         if self.filesystem.is_windows_fs:
             return self.abspath(filename)
         filename = make_string_path(filename)
@@ -388,17 +393,17 @@ class FakePathModule:
 
     @overload
     def _join_real_path(
-        self, path: str, rest: str, seen: Dict[str, Optional[str]]
-    ) -> Tuple[str, bool]: ...
+        self, path: str, rest: str, seen: dict[str, str | None]
+    ) -> tuple[str, bool]: ...
 
     @overload
     def _join_real_path(
-        self, path: bytes, rest: bytes, seen: Dict[bytes, Optional[bytes]]
-    ) -> Tuple[bytes, bool]: ...
+        self, path: bytes, rest: bytes, seen: dict[bytes, bytes | None]
+    ) -> tuple[bytes, bool]: ...
 
     def _join_real_path(
-        self, path: AnyStr, rest: AnyStr, seen: Dict[AnyStr, Optional[AnyStr]]
-    ) -> Tuple[AnyStr, bool]:
+        self, path: AnyStr, rest: AnyStr, seen: dict[AnyStr, AnyStr | None]
+    ) -> tuple[AnyStr, bool]:
         """Join two paths, normalizing and eliminating any symbolic links
         encountered in the second path.
         Taken from Python source and adapted.
@@ -473,7 +478,7 @@ class FakePathModule:
 
         Returns:
             `True` if path is a mount point added to the fake file system.
-            Under Windows also returns True for drive and UNC roots
+            Under Windows also returns `True` for drive and UNC roots
             (independent of their existence).
         """
         if not path:
@@ -482,7 +487,7 @@ class FakePathModule:
         normed_path = self.filesystem.absnormpath(path_str)
         sep = self.filesystem.path_separator
         if self.filesystem.is_windows_fs:
-            path_seps: Union[Tuple[str, Optional[str]], Tuple[str]]
+            path_seps: tuple[str, str | None] | tuple[str]
             if self.filesystem.alternative_path_separator is not None:
                 path_seps = (sep, self.filesystem.alternative_path_separator)
             else:
